/***********************************************************************************************************************
 *
 * OpenBlueSky - NetBeans Platform Enhancements
 * Copyright (C) 2006-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://openbluesky.kenai.com
 * SCM: https://kenai.com/hg/openbluesky~src
 *
 **********************************************************************************************************************/
package it.tidalwave.swing;

import javax.annotation.Nonnegative;
import javax.annotation.Nonnull;
import java.awt.Component;
import java.awt.Graphics;
import javax.swing.Icon;

/***********************************************************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 **********************************************************************************************************************/
public class ResizableIcon implements Icon 
  {
    @Nonnull
    private final Icon delegate;

    @Nonnull
    private final Icon original;

    public ResizableIcon (final @Nonnull Icon delegate,
                          final @Nonnegative int defaultSize)
      {
        this.original = delegate;
        this.delegate = IconResizer.scaledIcon(original, defaultSize);
      }  

    @Override
    public void paintIcon (final @Nonnull Component component,
                           final @Nonnull Graphics g,
                           final int x,
                           final int y)
      {
        delegate.paintIcon(component, g, y, y);
      }

    @Override
    public int getIconWidth() 
      {
        return delegate.getIconWidth();
      }

    @Override
    public int getIconHeight() 
      {
        return delegate.getIconHeight();
      }

    @Nonnull
    public Icon resized (final @Nonnegative int size)
      {
        return IconResizer.scaledIcon(delegate, size);
      }
  }
